# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased] 

## [1.1.0] - 2019-08-08
### Added
- Changelog file
- The ability to specify a sub-domain to connect to 

## [1.0.4] - 2019-08-07
### Changed
- Improve performance when converting raw data to pandas dataframe
- Use logging to log properly

## [1.0.3] - 2019-08-06
### Fixed
- Fix Error in documentation

## [1.0.2] - 2019-08-05
- Fix static pages not installed by the package

## [1.0.1] - 2019-08-05

### Fixed
- Fix static pages not included in the package

## [1.0.0] - 2019-03-21

### Added
- First release